@@ -1,10 +1,13 @@
 context("Display diff")
 library(LexisNexisTools)
 
-duplicates.df <- lnt_similarity(LNToutput = lnt_read(lnt_sample(verbose = FALSE),
-                                                     verbose = FALSE),
-                                threshold = 0.95,
-                                verbose = FALSE)
+duplicates.df <- lnt_similarity(
+  LNToutput = lnt_read(system.file("extdata", "sample.TXT", 
+                                   package = "LexisNexisTools"),
+                       verbose = FALSE),
+  threshold = 0.95,
+  verbose = FALSE
+)
 
 test_that("Show method", {
   expect_known_output(object = lnt_diff(duplicates.df,
@@ -23,7 +26,7 @@ test_that("lnt_diff warnings and errors", {
   #"'x' must contain a column with rel_dist information (see ?lnt_similarity)")
   expect_warning({
     class(duplicates.df) <- "data.frame"
-    diff <- capture_output( 
+    diff <- capture_output(
       lnt_diff(x = duplicates.df,
                min = 0.18,
                max = 0.30,
@@ -31,4 +34,3 @@ test_that("lnt_diff warnings and errors", {
   },
   "'x' should be an object returned by lnt_similarity().")
 })
-
